*****************************************************************************
*****************************************************************************
*** Beliefs about Inequality and the Nature of Support for Redistribution ***
*********************** Reproduction Package ********************************
*****************************************************************************






************************************
****** Set-up
************************************

clear all
set memory 100m
set more off

// set up paths: 
global workingdirectory "/Users/`c(username)'/." // SET THE PATH TO YOUR WORKING DIRECTORY FOLDER HERE. AFTERWARDS RUN THE WHOLE DO-FILE.
global data "$workingdirectory/data" 
global assets "$workingdirectory/assets" 
global graph "$assets/graphs"
global tex "$assets/tex"










************************************
****** Table 1
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

tab social_pref





************************************
****** Figure 3
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

hist deviation_top1_interval, frac discrete legend(off) xtitle("Misperceptions about the income share of the Top 1% (Prior Belief - Actual Share)") graphregion(fcolor(white)) color(gs8) xscale(range(1 11)) gap(10) xlabel(1 "<-5" 2 "[-5,5)" 3 "[5,15)" 4 "[15,25)" 5 "[25,35)" 6 "[35,45)" 7 "[45,55)" 8 "[55,65)" 9 "[65,75)" 10 "[75,85)" 11 "{&ge}85", labsize(small)) xscale(titlegap(*+10)) yscale(titlegap(*+10)) xsize(10) ysize(7)
graph export "$graph/Figure3.pdf", as(pdf) replace






************************************
****** Figure 4
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

// Shifting such that bars do not overlap
replace deviation_top1_interval = deviation_top1_interval -0.25 if social_pref==2
replace deviation_top1_interval = deviation_top1_interval +0.25 if social_pref==1

twoway (hist deviation_top1_interval if social_pref==2, frac discrete color(midblue) xscale(range(1 10)) gap(75) title(ia)) ///
(hist deviation_top1_interval if social_pref==3, frac discrete color(red) xscale(range(1 10)) gap(75) title(altruistic)) ///
(hist deviation_top1_interval if social_pref==1, frac discrete color(midgreen) xscale(range(1 10)) gap(75) title(selfish)), ///
legend(order(1 "Inequality Averse" 2 "Altruistic" 3 "Selfish") rows(3)) xtitle("Misperceptions about the income share of the Top 1% (Prior Belief - Actual Share)") graphregion(fcolor(white)) ylabel(0(0.05)0.2) yscale(range(0 0.2)) xlabel(1 "<-5" 2 "[-5,5)" 3 "[5,15)" 4 "[15,25)" 5 "[25,35)" 6 "[35,45)" 7 "[45,55)" 8 "[55,65)" 9 "[65,75)" 10 "[75,85)" 11 "{&ge}85", labsize(small)) xscale(titlegap(*+10)) yscale(titlegap(*+10)) title("") xsize(10) ysize(7)
graph export "$graph/Figure4.pdf", as(pdf) replace








************************************
****** Figure 5
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

graph twoway (scatter updating_belief_top1 deviation_top1 if updating_belief_top1<=20, jitter(8) color(gs10) msize(tiny)) (lfit updating_belief_top1 deviation_top1 if social_pref==2, color(midblue)) (lfit updating_belief_top1 deviation_top1 if social_pref==3, color(red)) (lfit updating_belief_top1 deviation_top1 if social_pref==1, color(midgreen)), ///
xsize(13) ysize(7) graphregion(color(white)) ///
xtitle("Misperceptions about the income share of the Top 1% (Prior Belief - Actual Share)")  ///
ytitle("Belief updating (Posterior Belief - Prior Belief)") xlabel(-10(10)90, labsize(vsmall)) xscale(titlegap(*+5)) ///
ylabel(-90(10)20, labsize(vsmall))  yscale(titlegap(*+5)) ///
title() subtitle() legend(order(2 3 4) pos(3) label(2 "Inequality Averse") label(3 "Altruistic") label(4 "Selfish") row(4)) 
graph export "$graph/Figure5.pdf", as(pdf) replace








************************************
****** Figure 6
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

// Snapshot
snapshot erase _all
snapshot save, label("full sample")
graph drop _all


** INEQUALITY AVERSE

snapshot restore 1

keep if social_pref==2
drop if income==15 // remove the income NA category

collapse (mean) mean_donation_redistribution = donation_redistribution (count) n = donation_redistribution (semean) se = donation_redistribution (sd) sd=donation_redistribution, by(income_high_2021 treatment)  // collapse the data by experimental condition & by income level groups

generate hiwrite_se = mean_donation_redistribution + se
generate lowrite_se = mean_donation_redistribution - se

gen axis=.
replace axis=1 if treatment==0 & income_high_2021==0
replace axis=1.5 if treatment==1 & income_high_2021==0
replace axis=3 if treatment==0 & income_high_2021==1
replace axis=3.5 if treatment==1 & income_high_2021==1

twoway (dot mean_donation_redistribution axis if treatment==0, ndots(0) msymbol(D) mcolor(red)) (dot mean_donation_redistribution axis if treatment==1, ndots(0) mcolor(blue)) (rcap hiwrite_se lowrite_se axis if treatment==0, lcolor(red)) (rcap hiwrite_se lowrite_se axis if treatment==1, lcolor(blue)), title("Inequality Averse", color(black) size(vlarge)) ytitle("Support for the 99% initiative in CHF (with standard errors)") ylabel(-2(1)11) yscale(titlegap(*+5)) graphregion(fcolor(white)) xlabel(1.25 `" "Below median"  "income" "'	3.25 `" "Above median"  "income" "', noticks nogrid labsize(medlarge)) xtitle("") legend(off) xscale(range(0.75 3.5)) ysize(5) xsize(4) yline(0, lcolor(black) lpattern(solid)) saving("$graph/donations_dotchart_IA_SE.gph", replace)	


** ALTRUISTIC: experimental condition & income-level

snapshot restore 1

keep if social_pref==3
drop if income==15 // remove the income NA category

collapse (mean) mean_donation_redistribution = donation_redistribution (count) n = donation_redistribution (semean) se = donation_redistribution (sd) sd=donation_redistribution, by(income_high_2021 treatment)  // collapse the data by experimental condition & by income level groups

generate hiwrite_se = mean_donation_redistribution + se
generate lowrite_se = mean_donation_redistribution - se

gen axis=.
replace axis=1 if treatment==0 & income_high_2021==0
replace axis=1.5 if treatment==1 & income_high_2021==0
replace axis=3 if treatment==0 & income_high_2021==1
replace axis=3.5 if treatment==1 & income_high_2021==1

twoway (dot mean_donation_redistribution axis if treatment==0, ndots(0) msymbol(D) mcolor(red)) (dot mean_donation_redistribution axis if treatment==1, ndots(0) mcolor(blue)) (rcap hiwrite_se lowrite_se axis if treatment==0, lcolor(red)) (rcap hiwrite_se lowrite_se axis if treatment==1, lcolor(blue)), title("Altruistic", color(black) size(vlarge)) ytitle("Support for the 99% initiative in CHF (with standard errors)") ylabel(-2(1)11) yscale(titlegap(*+5)) graphregion(fcolor(white)) xlabel(1.25 `" "Below median"  "income" "'	3.25 `" "Above median"  "income" "', noticks nogrid labsize(medlarge)) xtitle("") legend(off) xscale(range(0.75 3.5)) ysize(5) xsize(4) yline(0, lcolor(black) lpattern(solid)) saving("$graph/donations_dotchart_altruistic_SE.gph", replace)


** SELFISH: experimental condition & income-level

snapshot restore 1

keep if social_pref==1
drop if income==15 // remove the income NA category

collapse (mean) mean_donation_redistribution = donation_redistribution (count) n = donation_redistribution (semean) se = donation_redistribution (sd) sd=donation_redistribution, by(income_high_2021 treatment)  // collapse the data by experimental condition & by income level groups

generate hiwrite_se = mean_donation_redistribution + se
generate lowrite_se = mean_donation_redistribution - se

gen axis=.
replace axis=1 if treatment==0 & income_high_2021==0
replace axis=1.5 if treatment==1 & income_high_2021==0
replace axis=3 if treatment==0 & income_high_2021==1
replace axis=3.5 if treatment==1 & income_high_2021==1

twoway (dot mean_donation_redistribution axis if treatment==0, ndots(0) msymbol(D) mcolor(red)) (dot mean_donation_redistribution axis if treatment==1, ndots(0) mcolor(blue)) (rcap hiwrite_se lowrite_se axis if treatment==0, lcolor(red)) (rcap hiwrite_se lowrite_se axis if treatment==1, lcolor(blue)), title("Selfish", color(black) size(vlarge)) ytitle("Support for the 99% initiative in CHF (with standard errors)") ylabel(-2(1)11) yscale(titlegap(*+5)) graphregion(fcolor(white)) xlabel(1.25 `" "Below median"  "income" "'	3.25 `" "Above median"  "income" "', noticks nogrid labsize(medlarge)) xtitle("") legend(row(2) order(1 "Control" 2 "Treatment (shock in beliefs about inequality)") size(vlarge) region(lcolor(black))) xscale(range(0.75 3.5)) ysize(5) xsize(4) yline(0, lcolor(black) lpattern(solid)) saving("$graph/donations_dotchart_selfish_SE.gph", replace)


** COMBINE GRAPHS 

grc1leg2 "$graph/donations_dotchart_IA_SE.gph" "$graph/donations_dotchart_altruistic_SE.gph" "$graph/donations_dotchart_selfish_SE.gph", rows(1) ycommon xcommon legendfrom("$graph/donations_dotchart_selfish_SE.gph") graphregion(fcolor(white)) ysize(5) xsize(10) saving("$graph/donations_dotchart_combinded_SE.gph", replace) 
graph export "$graph/Figure6.pdf", as(pdf) replace










************************************
****** Table 2
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

est clear

eststo: xi: reg donation_redistribution treatment, r
test treatment = 0
estadd scalar p_zero_treatment = r(p)

eststo: xi: reg donation_redistribution treatment belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest, r
test treatment = 0
estadd scalar p_zero_treatment = r(p)

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar p_neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))
test treat_altruistic = 0
estadd scalar p_zero_treat_altruistic = r(p)
test treat_ia = treat_altruistic
estadd scalar p_treatia_eq_treataltruistic = r(p)
test treatment = 0
estadd scalar p_zero_treatment = r(p)
test treatment + treat_ia = 0
estadd scalar p_treat_plus_treatia = r(p)
test treatment + treat_altruistic = 0
estadd scalar p_treat_plus_treataltruistic = r(p)

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar p_neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))
test treat_altruistic = 0
estadd scalar p_zero_treat_altruistic = r(p)
test treat_ia = treat_altruistic
estadd scalar p_treatia_eq_treataltruistic = r(p)
test treatment = 0
estadd scalar p_zero_treatment = r(p)
test treatment + treat_ia = 0
estadd scalar p_treat_plus_treatia = r(p)
test treatment + treat_altruistic = 0
estadd scalar p_treat_plus_treataltruistic = r(p)

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic if income_high_2021==0, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar p_neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))
test treat_altruistic = 0
estadd scalar p_zero_treat_altruistic = r(p)
test treat_ia = treat_altruistic
estadd scalar p_treatia_eq_treataltruistic = r(p)
test treatment = 0
estadd scalar p_zero_treatment = r(p)
test treatment + treat_ia = 0
estadd scalar p_treat_plus_treatia = r(p)
test treatment + treat_altruistic = 0
estadd scalar p_treat_plus_treataltruistic = r(p)

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest if income_high_2021==0, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar p_neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))
test treat_altruistic = 0
estadd scalar p_zero_treat_altruistic = r(p)
test treat_ia = treat_altruistic
estadd scalar p_treatia_eq_treataltruistic = r(p)
test treatment = 0
estadd scalar p_zero_treatment = r(p)
test treatment + treat_ia = 0
estadd scalar p_treat_plus_treatia = r(p)
test treatment + treat_altruistic = 0
estadd scalar p_treat_plus_treataltruistic = r(p)

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic if income_high_2021==1, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar p_neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))
test treat_altruistic = 0
estadd scalar p_zero_treat_altruistic = r(p)
test treat_ia = treat_altruistic
estadd scalar p_treatia_eq_treataltruistic = r(p)
test treatment = 0
estadd scalar p_zero_treatment = r(p)
test treatment + treat_ia = 0
estadd scalar p_treat_plus_treatia = r(p)
test treatment + treat_altruistic = 0
estadd scalar p_treat_plus_treataltruistic = r(p)

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest if income_high_2021==1, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar p_neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))
test treat_altruistic = 0
estadd scalar p_zero_treat_altruistic = r(p)
test treat_ia = treat_altruistic
estadd scalar p_treatia_eq_treataltruistic = r(p)
test treatment = 0
estadd scalar p_zero_treatment = r(p)
test treatment + treat_ia = 0
estadd scalar p_treat_plus_treatia = r(p)
test treatment + treat_altruistic = 0
estadd scalar p_treat_plus_treataltruistic = r(p)

esttab using "$tex/Table2.tex",  b(3) se star(* 0.10 ** 0.05 *** 0.01)  stats(p_neg_treat_ia p_zero_treat_altruistic p_treatia_eq_treataltruistic p_zero_treatment p_treat_plus_treatia p_treat_plus_treataltruistic r2 N, fmt(3 3 3 3 3 3 3 0) ///
	label("p-value(Ho: Treat x IA $\geq$ 0)" "p-value(Ho: Treat x Altruistic = 0)" "p-value(Ho: Treat x IA = Treat x Altruistic)" "p-value(Ho: Treatment = 0)" "p-value(Ho: Treatment + Treat x IA = 0)" "p-value(Ho: Treatment + Treat x Altruistic = 0)" " $ R^2$" "Observations")) ///
	mgroups("Full sample" "Below median income" "Above median income" , pattern(1 0 0 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	label nonote gaps booktabs stardetach nomtitles obslast substitute(\_ _) ///
	indicate("Beliefs = belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich" "Socio-demographics = male age age2 french_2021 married" "Education = educDum2 educDum3 educDum4 educDum5" "Occupation = occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast" "Preference measures = z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all" "\shortstack[l]{Wealth bracket dummies\\\& financial assets} = _Iwealth* invest") ///
	replace	
	










************************************
****** Table B.1
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

ttest age, by(treatment)
ttest male, by(treatment)
ttest french_2021, by(treatment)

ttest incomeDum1, by(treatment)
ttest incomeDum2, by(treatment) 
ttest incomeDum3, by(treatment) 
ttest incomeDum4, by(treatment) 
ttest incomeDum5, by(treatment) 
ttest incomeDum6, by(treatment) 
ttest incomeDum7, by(treatment)

ttest successbelief_high_2021, by(treatment)

ttest belief_top1, by(treatment)
ttest inctop1belief_high_2021, by(treatment)

ttest inequality_averse, by(treatment)
ttest altruistic, by(treatment)
ttest selfish, by(treatment)










************************************
****** Table B.2
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution_inclwave2nonparticipants.dta", clear

est clear
eststo: reg efs2021 treatment, r
eststo: reg efs2021 inequality_averse_2020 altruistic_2020, r
eststo: reg efs2021 incomeDum1 incomeDum2 incomeDum3 incomeDum4 incomeDum5 incomeDum6, r
eststo: reg efs2021 successbelief_high_2020, r
eststo: reg efs2021 male age french_2020, r
eststo: reg efs2021 treatment inequality_averse_2020 altruistic_2020 incomeDum1 incomeDum2 incomeDum3 incomeDum4 incomeDum5 incomeDum6 successbelief_high_2020 male age french_2020, r
esttab using "$tex/TableB2.tex",  b(3) se star(* 0.10 ** 0.05 *** 0.01) stats(r2 N, fmt(3 0) ///
	label(" $ R^2$" "Observations")) ///
	label nonote nogaps booktabs stardetach nomtitles obslast substitute(\_ _) ///
	replace









************************************
****** Table C.1
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

tabulate social_pref

tabulate male social_pref, r nofreq
 
tabulate ageBracket1 social_pref, r nofreq 
tabulate ageBracket2 social_pref, r nofreq 
tabulate ageBracket3 social_pref, r nofreq 
tabulate ageBracket4 social_pref, r nofreq 
tabulate ageBracket5 social_pref, r nofreq 
tabulate ageBracket6 social_pref, r nofreq 
 
tabulate french_2021 social_pref, r nofreq

tabulate married social_pref, r nofreq

tabulate educDum1 social_pref, r nofreq
tabulate educDum2 social_pref, r nofreq
tabulate educDum3 social_pref, r nofreq
tabulate educDum4 social_pref, r nofreq
tabulate educDum5 social_pref, r nofreq

tabulate occupDum1 social_pref, r nofreq
tabulate occupDum2 social_pref, r nofreq
tabulate occupDum3 social_pref, r nofreq
tabulate occupDum4 social_pref, r nofreq
tabulate occupDum5 social_pref, r nofreq
tabulate occupDum6 social_pref, r nofreq

tabulate unemployedinpast social_pref, r nofreq









************************************
****** Table C.2
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

tabulate social_pref


tab riskLow social_pref, r nofreq

tab recpos1Low social_pref, r nofreq

tab recpos2Low social_pref, r nofreq

tab recneg1Low social_pref, r nofreq

tab recneg2Low social_pref, r nofreq

tab impatienceLow social_pref, r nofreq

tab trustLow social_pref, r nofreq


tab belief_top1Low social_pref, r nofreq

tab success_own_controlLow social_pref, r nofreq

tab incladdertop40Low social_pref, r nofreq

tab poverty_perceptionLow social_pref, r nofreq

tab gini_income_distrLow social_pref, r nofreq

tab gini_wealth_distrLow social_pref, r nofreq

tab incmobladderfutureLow social_pref, r nofreq

tab incmobladderpastLow social_pref, r nofreq

tab trustgov_enrichLow social_pref, r nofreq










************************************
****** Figure D.1
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

drop if income_high_2021==.

collapse (mean) mean_deviation_top1 = deviation_top1 (count) n = deviation_top1 (semean) se = deviation_top1 (sd) sd=deviation_top1, by(social_pref income_high_2021)  // collapse the data by social preference type AND income type

generate hiwrite_se = mean_deviation_top1 + se
generate lowrite_se = mean_deviation_top1 - se

gen axis=0
replace axis=1 if social_pref==2 & income_high_2021==0
replace axis=1.5 if social_pref==2 & income_high_2021==1
replace axis=3 if social_pref==3 & income_high_2021==0
replace axis=3.5 if social_pref==3 & income_high_2021==1
replace axis=5 if social_pref==1 & income_high_2021==0
replace axis=5.5 if social_pref==1 & income_high_2021==1

twoway (dot mean_deviation_top1 axis if income_high_2021==0, ndots(0) mcolor(navy)) (rcap hiwrite lowrite axis if income_high_2021==0, lcolor(navy)) ///
	(dot mean_deviation_top1 axis if income_high_2021==1, ndots(0) mcolor(maroon)) (rcap hiwrite lowrite axis if income_high_2021==1, lcolor(maroon)), ///
	ytitle("Misperceptions about the income share of the Top 1%" "(Prior Belief - Actual Share)", size(small)) ylabel(25(5)55) ///
	yscale(titlegap(*+5)) ///
	xscale(range(0.5 6)) ///
	graphregion(fcolor(white)) ///
	xlabel(1.25 "Inequality Averse" 3.25 "Altruistic" 5.25 "Selfish", noticks) xtitle("") ///
	legend(row(2) order(1 "Below median income" 3 "Above median income") size(small))
graph export "$graph/FigureD1.pdf", as(pdf) replace










************************************
****** Figure D.2
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

xtile decile = belief_top1, n(10) // generates deciles (x-axis variable)

corr income_distr_top1 belief_top1 // correlation between y and x (individual level)
scalar corrscal=r(rho)*100
local corr : display %6.2f corrscal

collapse (mean) income_distr_top1, by(decile)  // take the avg of y-variable, by decile

graph twoway (scatter income_distr_top1 decile, jitter(0) color(navy)), ///
xsize(5) ysize(5) graphregion(color(white)) xtitle("Deciles of Wave 2 prior belief of income share of top 1%")  ///
ytitle("Wave 1: Belief about income share of top 1%") xlabel(1(1)10) ylabel(0(10)60) title() subtitle() note("Correlation (individual level) : `corr' %") xscale(titlegap(*+5)) 
graph export "$graph/FigureD2.pdf", as(pdf) replace










************************************
****** Figure D.3
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

hist belief_top1, frac addplot(pci 0 12 .08 12) legend(off) xtitle("Prior belief of income share of top 1%") xlabel(0(10)100) xscale(titlegap(*+10)) yscale(titlegap(*+10)) discrete graphregion(fcolor(white)) color(gs8)
graph export "$graph/FigureD3.pdf", as(pdf) replace









************************************
****** Figure D.4
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

hist posterior_belief_top1, frac addplot(pci 0 12 .8 12) legend(off) xtitle("Posterior belief about income share of top 1%") xlabel(0(10)100) xscale(titlegap(*+10)) yscale(titlegap(*+10)) discrete graphregion(fcolor(white)) color(gs8)
graph export "$graph/FigureD4.pdf", as(pdf) replace









************************************
****** Figure D.5
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

// Inequality Averse
hist posterior_belief_top1 if social_pref==2, frac addplot(pci 0 12 .8 12) legend(off) xtitle("Posterior belief about income share of top 1%") xlabel(0(10)100) xscale(titlegap(*+10)) yscale(titlegap(*+10)) discrete graphregion(fcolor(white)) color(gs8)
graph export "$graph/FigureD5_InequalityAverse_hist.pdf", as(pdf) replace

preserve
keep if social_pref==2
cumul posterior_belief_top1 if treatment==1, gen(cum_posterior_IA)
sort cum_posterior_IA
line cum_posterior_IA posterior_belief_top1 if treatment==1, sort xline(12) xlabel(0(10)100) ylabel(0(.1)1) ytitle("Cumulative Distribution") xtitle("Posterior belief about income share of top 1%") xscale(titlegap(*+10)) graphregion(fcolor(white)) 
graph export "$graph/FigureD5_InequalityAverse_cum.pdf", as(pdf) replace
restore


// Altruistic
hist posterior_belief_top1 if social_pref==3, frac addplot(pci 0 12 .8 12) legend(off) xtitle("Posterior belief about income share of top 1%") xlabel(0(10)100) xscale(titlegap(*+10)) yscale(titlegap(*+10)) discrete graphregion(fcolor(white)) color(gs8)
graph export "$graph/FigureD5_Altruistic_hist.pdf", as(pdf) replace

preserve
keep if social_pref==3
cumul posterior_belief_top1 if treatment==1, gen(cum_posterior_altruistic)
sort cum_posterior_altruistic
line cum_posterior_altruistic posterior_belief_top1 if treatment==1, sort xline(12) xlabel(0(10)100) ylabel(0(.1)1) ytitle("Cumulative Distribution") xtitle("Posterior belief about income share of top 1%") xscale(titlegap(*+10)) graphregion(fcolor(white)) 
graph export "$graph/FigureD5_Altruistic_cum.pdf", as(pdf) replace
restore


// Selfish
hist posterior_belief_top1 if social_pref==1, frac addplot(pci 0 12 .8 12) legend(off) xtitle("Posterior belief about income share of top 1%") xlabel(0(10)100) xscale(titlegap(*+10)) yscale(titlegap(*+10)) discrete graphregion(fcolor(white)) color(gs8) 
graph export "$graph/FigureD5_Selfish_hist.pdf", as(pdf) replace

preserve
keep if social_pref==1
cumul posterior_belief_top1 if treatment==1, gen(cum_posterior_selfish)
sort cum_posterior_selfish
line cum_posterior_selfish posterior_belief_top1 if treatment==1, sort xline(12) xlabel(0(10)100) ylabel(0(.1)1) ytitle("Cumulative Distribution") xtitle("Posterior belief about income share of top 1%") xscale(titlegap(*+10)) graphregion(fcolor(white)) 
graph export "$graph/FigureD5_Selfish_cum.pdf", as(pdf) replace
restore









************************************
****** Figure D.6
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

hist donation_redistribution, frac legend(off) xtitle("Donation in favor of the 99% initiative") xlabel(-20(2)20, labsize(small)) xscale(titlegap(*+10)) yscale(titlegap(*+10)) lcolor(white) lwidth(vthin) discrete graphregion(fcolor(white)) color(gs8)
graph export "$graph/FigureD6.pdf", as(pdf) replace









************************************
****** Figure D.7
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

keep if treatment==0

collapse (mean) mean_donation_redistribution = donation_redistribution (count) n = donation_redistribution (semean) se = donation_redistribution (sd) sd = donation_redistribution, by(social_pref)  // collapse the data by social preference type

generate hiwrite_se = mean_donation_redistribution + se
generate lowrite_se = mean_donation_redistribution - se

gen axis=0
replace axis=1 if social_pref==2
replace axis=2 if social_pref==3
replace axis=3 if social_pref==1

twoway (dot mean_donation_redistribution axis if social_pref==2, ndots(0) mcolor(midblue)) (rcap hiwrite_se lowrite_se axis if social_pref==2, lcolor(midblue)) ///
	(dot mean_donation_redistribution axis if social_pref==3, ndots(0) mcolor(red)) (rcap hiwrite_se lowrite_se axis if social_pref==3, lcolor(red)) ///
	(dot mean_donation_redistribution axis if social_pref==1, ndots(0) mcolor(midgreen)) (rcap hiwrite_se lowrite_se axis if social_pref==1, lcolor(midgreen)), ///
	ytitle("Support for the 99% initiative (in CHF)") ylabel(-1(1)10) ///
	yscale(titlegap(*+5)) ///
	xscale(range(0.5 3.5)) ///
	graphregion(fcolor(white)) ///
	xlabel(1 "Inequality Averse" 2 "Altruistic" 3 "Selfish", noticks) xtitle("") ///
	legend(off) 
graph export "$graph/FigureD7.pdf", as(pdf) replace










************************************
****** Table D.1
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

est clear

eststo: xi: reg donation_redistribution treatment, r

eststo: xi: reg donation_redistribution treatment belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest, r

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))


eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic if income_high_2021==0, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest if income_high_2021==0, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic if income_high_2021==1, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest if income_high_2021==1, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

esttab using "$tex/TableD1.tex",  b(3) se star(* 0.10 ** 0.05 *** 0.01)  stats(neg_treat_ia r2 N, fmt(3 3 0) ///
	label("p-value(Ho: Treat x IA $\geq$ 0)" " $ R^2$" "Observations")) ///
	mgroups("Full sample" "Below median income" "Above median income" , pattern(1 0 0 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	label nonote gaps booktabs stardetach nomtitles obslast substitute(\_ _) ///
	indicate("Wealth bracket dummies = _Iwealth*") ///
	order(treatment inequality_averse altruistic treat_ia treat_altruistic) ///
	replace	










************************************
****** Table D.2
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

drop if screener_passes_2021==0

est clear

eststo: xi: reg donation_redistribution treatment, r

eststo: xi: reg donation_redistribution treatment belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest, r

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))


eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic if income_high_2021==0, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest if income_high_2021==0, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic if income_high_2021==1, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest if income_high_2021==1, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

esttab using "$tex/TableD2.tex",  b(3) se star(* 0.10 ** 0.05 *** 0.01)  stats(neg_treat_ia r2 N, fmt(3 3 0) ///
	label("p-value(Ho: Treat x IA $\geq$ 0)" " $ R^2$" "Observations")) ///
	mgroups("Full sample" "Below median income" "Above median income" , pattern(1 0 0 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	label nonote gaps booktabs stardetach nomtitles obslast substitute(\_ _) ///
	indicate("Beliefs = belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich" "Socio-demographics = male age age2 french_2021 married" "Education = educDum2 educDum3 educDum4 educDum5" "Occupation = occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast" "Preference measures = z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all" "\shortstack[l]{Wealth bracket dummies\\\& financial assets} = _Iwealth* invest") ///
	order(treatment inequality_averse altruistic treat_ia treat_altruistic) ///
	replace	










************************************
****** Table D.3
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

keep if screener_passes_2021==2

est clear

eststo: xi: reg donation_redistribution treatment, r

eststo: xi: reg donation_redistribution treatment belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest, r

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))


eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic if income_high_2021==0, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest if income_high_2021==0, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic if income_high_2021==1, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest if income_high_2021==1, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

esttab using "$tex/TableD3.tex",  b(3) se star(* 0.10 ** 0.05 *** 0.01)  stats(neg_treat_ia r2 N, fmt(3 3 0) ///
	label("p-value(Ho: Treat x IA $\geq$ 0)" " $ R^2$" "Observations")) ///
	mgroups("Full sample" "Below median income" "Above median income" , pattern(1 0 0 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	label nonote gaps booktabs stardetach nomtitles obslast substitute(\_ _) ///
	indicate("Beliefs = belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich" "Socio-demographics = male age age2 french_2021 married" "Education = educDum2 educDum3 educDum4 educDum5" "Occupation = occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast" "Preference measures = z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all" "\shortstack[l]{Wealth bracket dummies\\\& financial assets} = _Iwealth* invest") ///
	order(treatment inequality_averse altruistic treat_ia treat_altruistic) ///
	replace	









************************************
****** Table D.4
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

drop if belief_top1<=12

est clear

eststo: xi: reg donation_redistribution treatment, r

eststo: xi: reg donation_redistribution treatment belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest, r

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic if income_high_2021==0, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest if income_high_2021==0, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic if income_high_2021==1, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest if income_high_2021==1, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

esttab using "$tex/TableD4.tex",  b(3) se star(* 0.10 ** 0.05 *** 0.01)  stats(neg_treat_ia r2 N, fmt(3 3 0) ///
	label("p-value(Ho: Treat x IA $\geq$ 0)" " $ R^2$" "Observations")) ///
	mgroups("Full sample" "Below median income" "Above median income" , pattern(1 0 0 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	label nonote gaps booktabs stardetach nomtitles obslast substitute(\_ _) ///
	indicate("Beliefs = belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich" "Socio-demographics = male age age2 french_2021 married" "Education = educDum2 educDum3 educDum4 educDum5" "Occupation = occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast" "Preference measures = z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all" "\shortstack[l]{Wealth bracket dummies\\\& financial assets} = _Iwealth* invest") ///
	replace	









************************************
****** Table D.5
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

keep if belief_top1>21

est clear

eststo: xi: reg donation_redistribution treatment, r

eststo: xi: reg donation_redistribution treatment belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest, r

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic if income_high_2021==0, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest if income_high_2021==0, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic if income_high_2021==1, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg donation_redistribution treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest if income_high_2021==1, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

esttab using "$tex/TableD5.tex",  b(3) se star(* 0.10 ** 0.05 *** 0.01)  stats(neg_treat_ia r2 N, fmt(3 3 0) ///
	label("p-value(Ho: Treat x IA $\geq$ 0)" " $ R^2$" "Observations")) ///
	mgroups("Full sample" "Below median income" "Above median income" , pattern(1 0 0 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	label nonote gaps booktabs stardetach nomtitles obslast substitute(\_ _) ///
	indicate("Beliefs = belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich" "Socio-demographics = male age age2 french_2021 married" "Education = educDum2 educDum3 educDum4 educDum5" "Occupation = occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast" "Preference measures = z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all" "\shortstack[l]{Wealth bracket dummies\\\& financial assets} = _Iwealth* invest") ///
	replace	
		









************************************
****** Table D.6
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

est clear

eststo: xi: reg redist_pref_average_2021 treatment, r

eststo: xi: reg redist_pref_average_2021 treatment belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest, r

eststo: xi: reg redist_pref_average_2021 treatment inequality_averse altruistic treat_ia treat_altruistic, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg redist_pref_average_2021 treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg redist_pref_average_2021 treatment inequality_averse altruistic treat_ia treat_altruistic if income_high_2021==0, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg redist_pref_average_2021 treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest if income_high_2021==0, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg redist_pref_average_2021 treatment inequality_averse altruistic treat_ia treat_altruistic if income_high_2021==1, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg redist_pref_average_2021 treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest if income_high_2021==1, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

esttab using "$tex/TableD6.tex",  b(3) se star(* 0.10 ** 0.05 *** 0.01)  stats(neg_treat_ia r2 N, fmt(3 3 0) ///
	label("p-value(Ho: Treat x IA $\geq$ 0)" " $ R^2$" "Observations")) ///
	mgroups("Full sample" "Below median income" "Above median income" , pattern(1 0 0 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	label nonote gaps booktabs stardetach nomtitles obslast substitute(\_ _) ///
	indicate("Beliefs = belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich" "Socio-demographics = male age age2 french_2021 married" "Education = educDum2 educDum3 educDum4 educDum5" "Occupation = occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast" "Preference measures = z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all" "\shortstack[l]{Wealth bracket dummies\\\& financial assets} = _Iwealth* invest") ///
	replace	
		
	









************************************
****** Table D.7
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

est clear

eststo: xi: reg redist_pref_tax_rich_2021 treatment, r

eststo: xi: reg redist_pref_tax_rich_2021 treatment belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest, r

eststo: xi: reg redist_pref_tax_rich_2021 treatment inequality_averse altruistic treat_ia treat_altruistic, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg redist_pref_tax_rich_2021 treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg redist_pref_tax_rich_2021 treatment inequality_averse altruistic treat_ia treat_altruistic if income_high_2021==0, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg redist_pref_tax_rich_2021 treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest if income_high_2021==0, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg redist_pref_tax_rich_2021 treatment inequality_averse altruistic treat_ia treat_altruistic if income_high_2021==1, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg redist_pref_tax_rich_2021 treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest if income_high_2021==1, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

esttab using "$tex/TableD7.tex",  b(3) se star(* 0.10 ** 0.05 *** 0.01)  stats(neg_treat_ia r2 N, fmt(3 3 0) ///
	label("p-value(Ho: Treat x IA $\geq$ 0)" " $ R^2$" "Observations")) ///
	mgroups("Full sample" "Below median income" "Above median income" , pattern(1 0 0 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	label nonote gaps booktabs stardetach nomtitles obslast substitute(\_ _) ///
	indicate("Beliefs = belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich" "Socio-demographics = male age age2 french_2021 married" "Education = educDum2 educDum3 educDum4 educDum5" "Occupation = occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast" "Preference measures = z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all" "\shortstack[l]{Wealth bracket dummies\\\& financial assets} = _Iwealth* invest") ///
	replace	
		









************************************
****** Table D.8
************************************

use "$data/BeliefsInequalityNatureSupportRedistribution.dta", clear

est clear

eststo: xi: reg redist_pref_support_poor_2021 treatment, r

eststo: xi: reg redist_pref_support_poor_2021 treatment belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest, r

eststo: xi: reg redist_pref_support_poor_2021 treatment inequality_averse altruistic treat_ia treat_altruistic, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg redist_pref_support_poor_2021 treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg redist_pref_support_poor_2021 treatment inequality_averse altruistic treat_ia treat_altruistic if income_high_2021==0, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg redist_pref_support_poor_2021 treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest if income_high_2021==0, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg redist_pref_support_poor_2021 treatment inequality_averse altruistic treat_ia treat_altruistic if income_high_2021==1, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

eststo: xi: reg redist_pref_support_poor_2021 treatment inequality_averse altruistic treat_ia treat_altruistic belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich male age age2 french_2021 married educDum2 educDum3 educDum4 educDum5 occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all i.wealth invest if income_high_2021==1, r
test _b[treat_ia]=0
local sign_treat_ia=sign(_b[treat_ia])
estadd scalar neg_treat_ia=1-ttail(r(df_r),`sign_treat_ia'*sqrt(r(F)))

esttab using "$tex/TableD8.tex",  b(3) se star(* 0.10 ** 0.05 *** 0.01)  stats(neg_treat_ia r2 N, fmt(3 3 0) ///
	label("p-value(Ho: Treat x IA $\geq$ 0)" " $ R^2$" "Observations")) ///
	mgroups("Full sample" "Below median income" "Above median income" , pattern(1 0 0 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	label nonote gaps booktabs stardetach nomtitles obslast substitute(\_ _) ///
	indicate("Beliefs = belief_top1 z_success_own_control z_incladdertop40 z_poverty_perception gini_income_distr gini_wealth_distr z_incmobladderfuture z_incmobladderpast z_trustgov_enrich" "Socio-demographics = male age age2 french_2021 married" "Education = educDum2 educDum3 educDum4 educDum5" "Occupation = occupDum2 occupDum3 occupDum4 occupDum5 occupDum6 unemployedinpast" "Preference measures = z_riskpsm_all z_recpos1psm_all z_recpos2psm_all z_recneg1psm_all z_recneg2psm_all z_impatiencepsm_all z_trustpsm_all" "\shortstack[l]{Wealth bracket dummies\\\& financial assets} = _Iwealth* invest") ///
	replace	
