suppressPackageStartupMessages({
  library(tidyverse)
  library(RColorBrewer)
})

"./data/socialTypes.csv" %>%
  read_csv(show_col_types = FALSE) %>%
  mutate(     take = case_when( z <  (1/6 + .02) ~ "own-payoff minimizing choices"
                              , z >= (5/6 - .02) ~ "own-payoff maximizing choices"
                              ,             TRUE ~ "payoff-equalizing choices"
                              ) %>% as.factor()
        ,     type = case_when( type == 1 ~ "Selfish"
                              , type == 2 ~ "Inequality averse"
                              , type == 3 ~ "Altruistic"
                              ) %>% as.factor()
        , posSlope = if_else(slope > 0, "positive", "negative")
        ,     type = fct_relevel(type, "Inequality averse", "Altruistic", "Selfish")
        ,     take = fct_relevel(take, levels(take)[c(2,3,1)])
        ) %>%
  ggplot(aes(x = posSlope, fill = take)) +
  geom_bar( aes(y = after_stat(count/sum(count)))
          , position = "fill"
          ) +
  facet_grid(   rows = vars(type)
            , scales = "free"
            ,  space = "free"
            , switch = "y"
            ) +
  labs(    x = "slope"
      ,    y = "relative frequency"
      , fill = "Relative share of"
      ) +
  scale_y_continuous( breaks = seq(0, 1, by = .25)
                    , labels = seq(0, 1, by = .25)
                    , limits = c(0, 1)
                    , sec.axis = sec_axis(~ ., name = "proportion")
                    ) +
  scale_fill_manual( values = brewer.pal(4, "YlOrBr")[2:4] ) +
  guides( fill = guide_legend(  nrow = 3
                             , byrow = TRUE
                             , title.position = "top"
                             )
        ) +
  theme_bw() +
  theme(         plot.title = element_text(size = 10, hjust = .5)
       ,       axis.title.y = element_blank()
       ,        axis.text.y = element_blank()
       ,       axis.ticks.y = element_blank()
       , axis.title.y.right = element_text(angle = 90, vjust = .5)
       ,  axis.text.y.right = element_text()
       , axis.ticks.y.right = element_line()
       ,       strip.text.y = element_text(size = 12, face = "bold")
       ,       strip.text.x = element_text(size = 12, face = "bold")
       ,    legend.position = "bottom"
       ,       legend.title = element_text(face = "bold")
       ) ->
  p

ggsave( filename = "./out/allocPlot.pdf"
      , plot = p
      , width = 3.5
      , height = 7.5
      )
